aboutsummaryrefslogtreecommitdiff
path: root/examples
diff options
context:
space:
mode:
authorJustin Bedo <cu@cua0.org>2024-11-12 15:50:42 +1100
committerJustin Bedo <cu@cua0.org>2024-11-12 15:50:42 +1100
commit58fa67ffd09d3bdfe72bef7c873ef94190dc6708 (patch)
tree9e382c5b1da76540d6b1ca2d9a053f52042e3579 /examples
parent00d758934e7d5827e01585887a36913a326535ea (diff)
deprecate platypusHEADmaster
Diffstat (limited to 'examples')
-rw-r--r--examples/call.nix8
1 files changed, 4 insertions, 4 deletions
diff --git a/examples/call.nix b/examples/call.nix
index 81a112e..7525835 100644
--- a/examples/call.nix
+++ b/examples/call.nix
@@ -1,7 +1,7 @@
# This is an example pipeline specification to do multi-sample variant calling
# with the Platypus variant caller. Each input is preprocessed by aligning
# against a reference genome (defaults to GRCH38), fixing mate information, and
# marking duplicates. Finally platypus is called over all samples.
{ bionix ? import <bionix> { }
, inputs
, ref ? bionix.ref.grch38.seq
@@ -12,7 +12,7 @@ with lib;
let
preprocess = flip pipe [
- (bwa.align { inherit ref; })
+ (bwa.align { inherit ref; RG = {SM = "sample"; ID = "sample";};})
(samtools.sort { nameSort = true; })
(samtools.fixmate { })
(samtools.sort { })
@@ -20,4 +20,4 @@ let
];
in
-platypus.call { } (map preprocess inputs)
+octopus.call { } (map preprocess inputs)
@@ -1,7 +1,7 @@
# This is an example pipeline specification to do multi-sample variant calling
-# with the Platypus variant caller. Each input is preprocessed by aligning
+# with the Octopus variant caller. Each input is preprocessed by aligning
# against a reference genome (defaults to GRCH38), fixing mate information, and
@@ -1,7 +1,7 @@
# against a reference genome (defaults to GRCH38), fixing mate information, and
-# marking duplicates. Finally platypus is called over all samples.
+# marking duplicates. Finally octopus is called over all samples.
{ bionix ? import <bionix> { }
, inputs